% DLOAD  Load FEM data from FEMLAB
% [EXI,EYI,EZI,XI,YI,ZI] = DLOAD (DX,MX,MN)imports data from FEMLABv3 into
% MATLAB for use by STREAMFORCE.  It returns the data in three 3-D field
% matrices along with analogous XI, YI, and ZI matrices.
%
%  Inputs: 
%	    DX		1x3 vector with [dx dy dz] of density to grid data
%	    MN		1x3 vector with [xmin ymin zmin] of space to grid data
%	    MX		1x3 vector with [xmax ymax zmax] of space to grid data
%
%  Outputs: 
%       EXI,EYI,EZI	    These are n x m x p matrices of each vector 
%			            field component in space
%	    XI, YI, ZI      Spatial grid
%

function [ex,ey,ez,xi,yi,zi] = dload(dx,mx,mn,fem)

fprintf('Loading data -- ');
% First, generate 3-D grid matrices
fprintf('grid');
[xi,yi,zi] = meshgrid(mn(1):dx(1):mx(1),mn(2):dx(2):mx(2),mn(3):dx(3):mx(3));

% Put them into columns for use with FEMLAB
xx=[xi(:),yi(:),zi(:)]'; 

% Pull data from FEMLAB into vectors
fprintf('...extract FEMLAB data');
[exi eyi ezi] = postinterp(fem,'Ex','Ey','Ez',xx);

% Reshape vectors into matrices
fprintf('...reshape');
ex = reshape(exi,size(xi,1), size(xi,2), size(xi,3));
ey = reshape(eyi,size(xi,1), size(xi,2), size(xi,3));
ez = reshape(ezi,size(xi,1), size(xi,2), size(xi,3));
fprintf('\n');
