% Determines if particle still trapped by calculating the x and z end
% position of the particle - where the particle finally stops. If the
% particle is trapped, this will be within the given FEMLAB geometry. If
% the particle is not trapped, this will be outside the geometry. Trapping
% is checked by seeing if the endpoint of the particle trajectory is within
% a threshold of the extents of the geometry.  This is the criterion for 
% going to the next highest flow rate.
%
% There are two outputs: RES is a M-by-N cell array--where M is the length
% of the outer loop and N is the length of the inner loop--that holds in
% each cell the voltage, inner loop value, flowrate, endpoint, drag and
% field at each flowrate, while ANSW is a MxN-by-9 array that holds only
% the final values at each condition.

% Nitzan 8/31/2004 - Changed the loop that steps Q from a for ("for Q =
% startQ:stepQ:endQ") loop to a while loop that uses the "notfinished"
% flag.

res = cell(length(vec1),length(vec2));               % initialize RES cell array
answ = zeros(length(vec1)*length(vec2),9);           % initialize ANSW output array
lin = 0;                                             % to specify line in output array
Q = startQ;                                          % initialize start flowrate
for oloop= 1:length(vec1);                                     % run outer loop: voltage
    V=vec1(oloop);                      
    for iloop=1:length(vec2);                                  % run inner loup
        fprintf(['V = %g, ',var2,' = %g\n'],V,vec2(iloop));
        evalin('base',[var2,'=',num2str(vec2(iloop)),';']);    %assign var2 name
        totfor;                                                % calculate all the forces
        normE=sqrt(real(Ex).^2 + real(Ey).^2 + real(Ez).^2);   %calculate normalized electric field
        endpt = [];                                            % initializes particle end position to null
        lin = lin + 1;                                         % increments line number for answer output array
        fprintf('stepping Q =      ');
        k = 0;                                                 % reset incremental counter
        Q = startQ;                                            % initialize Q
        notfinished = 1;                                     % flag to exit loop when max flowrate has been reached
        while notfinished,
            if isinregion(x,y,z,endpt,thresh)        % if particle is trapped
                if Q*60/1e-9<10;fprintf('\b\b\b\b%2.2f',Q*60/1e-9);
                elseif 10<=(Q*60/1e-9)<100;fprintf('\b\b\b\b\b%2.2f',Q*60/1e-9);
                elseif 100<=(Q*60/1e-9)<1000;fprintf('\b\b\b\b\b\b%2.2f',Q*60/1e-9);
                elseif 1000<=(Q*60/1e-9)<10000;fprintf('\b\b\b\b\b\b\b%2.2f',Q*60/1e-9);end
                calcdrag
                Ft(:,:,:,1) = pol*Fdep(:,:,:,1) + Fdrag;                 % add in drag force 
                calclift                                                 % calculate lift force
                Ft(:,:,:,3) = pol*Fdep(:,:,:,3) + Flift+Fgrav;           % calculate total z force
                Ft(:,:,:,3) = rigidbound(Ft(:,:,:,3),x,y,z,obj.R,off);   % accounting for effect of boundaries

                % find trajectory of particle
                [endpt,startpt]=findtraj(x,y,z,Ft,obj.start,obj.R,figinfo,normE,sliceplane);
                %endpt*1e6
                
                % store all intermediate values in cell array RES
                k=k+1;
                res{oloop,iloop}(k,1:7) = [V vec2(iloop) Q Q*6e10 endpt*1e6];
                res{oloop,iloop}(k,8) = interp1(squeeze(z(1,1,:)),Fdrag0,endpt(3));     % dragforce at particle center
                res{oloop,iloop}(k,9) = interp3(x,y,z,Fdep(:,:,:,1),endpt(1),endpt(2),endpt(3));    
       			res{oloop,iloop}(k,10) = interp3(x,y,z,Fdep(:,:,:,2),endpt(1),endpt(2),endpt(3));        
                res{oloop,iloop}(k,11)= interp3(x,y,z,Fdep(:,:,:,3),endpt(1),endpt(2),endpt(3)); 
                res{oloop,iloop}(k,12) = interp3(x,y,z,Fgrav,endpt(1),endpt(2),endpt(3)); 
                res{oloop,iloop}(k,13) = interp3(x,y,z,Flift,endpt(1),endpt(2),endpt(3)); 
                
                % if we're still in region, record relevant values into matrix ANSW, else we
                % have the ones from last iteration
                if isinregion(x,y,z,endpt,thresh)
                  answ(lin,1:8) = [V obj.R*1e6 f*1e-6 Q Q*6e10 endpt*1e6];
                  answ(lin,9) = res{oloop,iloop}(k,7)*1e12;
                  answ(lin,10) = res{oloop,iloop}(k,8)*1e12;
                  answ(lin,11) = res{oloop,iloop}(k,9)*1e12;
                  answ(lin,12) = res{oloop,iloop}(k,10)*1e12;
                  answ(lin,13) = res{oloop,iloop}(k,11)*1e12;
                  answ(lin,14) = res{oloop,iloop}(k,12)*1e12;
                
                end
                Q = Q + stepQ;                                              % step to next Q
            else
                notfinished = 0;                                            % set flag to 0 to exit loop
            end
        end
        fprintf('\n');
    end
end