% ISINREGION   Is point in rectangular region
%   ISINREGION(X,Y,Z,POINT,THRESHOLD) determines if POINT is within a
%   THRESHOLD distance of the extents of space X,Y,Z.  It returns 1 if
%   point is within region and 0 if it is not.
%
% If THRESHOLD is not specified, assumes THRESHOLD is 0 in X,Y,Z
%
% Inputs:
%       X,Y,Z       space variables
%       POINT       1x3 vector of point to test
%       THRESHOLD   1x3 vector of threshold distance in x,y,z
%

function result=isinregion(x,y,z,pt,varargin)

% assign threshold
if nargin==5
    th=varargin{1};
else
    th=[0 0 0];
end

% find region limits
limx = [min(min(min(x))) max(max(max(x)))];
limy = [min(min(min(y))) max(max(max(y)))];
limz = [min(min(min(z))) max(max(max(z)))];

%initialize output
result=0;

% if PT is a null vector, return immediately and say that it is within
% region.  Use this to check dummy points
if isempty(pt)
    result=1;
    return
end

%check to make sure point is within threshold of rectangular region
if  and( pt(1)>limx(1)+th(1) , pt(1)<limx(2)-th(1) )
    if and( pt(2)>limy(1)+th(2) , pt(2)<limy(2)-th(2) )
        if and( pt(3)>limz(1) , pt(3)<limz(2)-th(3) )    %bottom z check w/o threshold b/c of cases when R < th(3)
            result=1;  %if so, change result
        end
    end
end


