%This is the control center of forcesim. All the inputs that will ever
%be changed should be contained in this file. No file in the executable 
%(bin directory should ever need to be touched in forcesim.
%author: Joel Voldman
%revised: Adam Rosenthal 5/24/04

reload=1;                                            % 1 to reload field data
format short g;                                      % makes the output in most readable format
bindir =   '..\bin';                                 % dir with m-file executables
addpath(bindir);                                     % add bin directory to path

%fieldfile = 'FEM.mat';                               % specify data filename to 
                                                     % load from disk if desired                                                    % desired

if reload       % if reloading fields from scratch
    if exist('fieldfile') & ~isempty(fieldfile) % check to see if we want to use stored data
        if exist(fieldfile) % and make sure file actually exists
          fprintf([' - using pre-existing data file ',fieldfile,'\n'])
          dx=[];mn=[];mx=[];smth=[];                 % set these to dummy
          load(fieldfile)
        else
          error('fieldfile not found');
        end
    else
        % dload info
        dx = 1e-6 * [1 1 1];                                % (x,y,z) step for FEMLAB geometry (um)   
        mn = 1e-6 * [-5 -10 0];                             % (x,y,z) minimums for FEMLAB geometry (um); zmin = 0
        mx = 1e-6 * [15 10 40];                             % (x,y,z) maximums for FEMLAB geometry (um); zmax = chamber height
        [ExI,EyI,EzI,XI,YI,ZI] = dload(dx,mx,mn,fem);            % transfers geometry and fields from FEMLAB
        
        smth=3;                                             % smooth FEM field data
        for in3=1:smth                                      % different amounts of smoothing
            ExI=smooth3(ExI,'gaussian',3,0.65*2);           % can affect results!
            EyI=smooth3(EyI,'gaussian',3,0.65*2);
            EzI=smooth3(EzI,'gaussian',3,0.65*2);
        end
    end    
end



% Define problem Variables 
vec1 = [5];                                 % vector of voltage values
var2 = 'obj.R';                                     % name of second variable to vary, can be anything
vec2 = 1e-6* [1:1:7];                                   % second variable values
fdr =1;			                                    % direction of x-directed flow in relation to FEM model, either +x or -x
Vsim = 5;                                           % Applied voltage difference during FEMLAB sims
media.rho=1000;	                                    % density of medium (kg/m^3)
media.sig=0.01;                                      % cell culture media conductivity (S/m)
media.eps=80;                                        % rel. media permittivity 
obj.type = 'cell';	                                 % specify object
obj.sig=2e-4;                                        % specific object properties to include
obj.eps=2.5;                                         % are determined by CMFACTOR
f = 5e6;		                                     % freq. of applied signal (Hz)
nmax = 6;		                                     % Maximum order to calculate force (dipole, quad, oct, etc.)
pol = 1;                                             % polarization factor, if there is electrode polarization
h = 40e-6;                                          % Height of channel (m)
w = 4e-3;		                                     % Width of channel (m)
off=0;				                                 % Minimum offset of bead from substrate (m), to prevent bead
                                                     % from touching ground, if desired
typ=1;				                                 % kind of flow profile/interp to use, see dragforce.m for details.
startQ =10*1e-9/60;                                     % starting flow rate (m^3/s)
endQ = 500/60*1e-9/60;                                  % ending flow rate (m^3/s)
stepQ = 10*1e-9/60;                                     % how much to step flow rate between guesses (m^3/s)
thresh = [2e-6 2e-6 2e-6];                           % distance (m) from edge of space to determine if particle still trapped, not for bottom z
obj.start = {'0' '0' 'obj.R'};                         % starting object position for streamline (um), can be cell or numeric array
liftfactor = 1;                                      % set to 0 to not include lift force, set to 1 to include lift force
figinfo = 1;                                         % 0 = surpress figure, 1 = plot streamlines, 2 = plot streamlines in diff. figs
sliceplane = {[],[],1e-6};                           % where to draw slice planes for stream plots

hforce3;                                             % calls hforce program to do trap analysis
fprintf('            V          R(um)        f(MHz)     Q(m^3/s)     Q(uL/min)     x(um)        y(um)')
fprintf('        z(um)        Fx(N)     Emax(V/m)\n')
disp(answ)

% Pack and save variables and answer into file 'test' in order to be able to rerun
% simulation later
save 'test' dx mn mx smth ExI EyI EzI XI YI ZI vec1 vec2 var2 fdr ...
   Vsim media obj f nmax pol h w off typ startQ endQ stepQ thresh ...
   liftfactor figinfo sliceplane answ res